@@ -104,6 +104,29 @@ static GObjectClass *parent_class;
 //#define DEBUG_PRINT(format_MACRO,...)           g_print (format_MACRO, ##__VA_ARGS__);
 #define DEBUG_PRINT(format_MACRO,...)             
 
+/* do not call brasero_*_start() at nautilus startup, they are very expensive;
+ * lazily initialize those instead */
+static void
+ensure_initialized()
+{
+	static gboolean initialized = FALSE;
+	GConfClient *client;
+
+	if (!initialized) {
+		client = gconf_client_get_default ();
+		if (gconf_client_get_bool (client, "/apps/brasero/nautilus-extension-debug", NULL)) {
+		    brasero_media_library_set_debug (TRUE);
+		    brasero_burn_library_set_debug (TRUE);
+		}
+		g_object_unref (client);
+
+		brasero_media_library_start ();
+		brasero_burn_library_start (NULL, NULL);
+
+		DEBUG_PRINT ("Libbrasero-media started\n");
+		initialized = TRUE;
+	}
+}
 
 static void
 launch_brasero_on_window_session (BraseroSessionCfg	*session,
@@ -242,6 +265,8 @@ write_activate (GtkWindow *toplevel)
 	if (nautilus_disc_burn_is_empty (toplevel))
 		return;
 
+	ensure_initialized ();
+
 	track = brasero_track_data_cfg_new ();
 	brasero_track_data_cfg_add (track, BURN_URI, NULL);
 
@@ -313,6 +338,8 @@ write_iso_activate_cb (NautilusMenuItem *item,
         NautilusFileInfo	*file_info;
         char			*uri;
 
+	ensure_initialized();
+
         file_info = g_object_get_data (G_OBJECT (item), "file_info");
         uri = nautilus_file_info_get_uri (file_info);
 
@@ -335,6 +362,8 @@ copy_disc_activate_cb (NautilusMenuItem *item,
 	BraseroTrackDisc	*track;
 	BraseroDrive		*drive;
 
+	ensure_initialized();
+
         device_path = g_object_get_data (G_OBJECT (item), "drive_device_path");
 	monitor = brasero_medium_monitor_get_default ();
 	drive = brasero_medium_monitor_get_drive (monitor, device_path);
@@ -392,6 +421,8 @@ blank_disc_activate_cb (NautilusMenuItem *item,
 {
 	BraseroBlankDialog *dialog;
 
+	ensure_initialized();
+
 	dialog = brasero_blank_dialog_new ();
 	tool_dialog_run (BRASERO_TOOL_DIALOG (dialog),
 			 GTK_WINDOW (user_data),
@@ -404,6 +435,8 @@ check_disc_activate_cb (NautilusMenuItem *item,
 {
 	BraseroSumDialog *dialog;
 
+	ensure_initialized ();
+
 	dialog = brasero_sum_dialog_new ();
 	tool_dialog_run (BRASERO_TOOL_DIALOG (dialog),
 			 GTK_WINDOW (user_data),
@@ -475,7 +508,12 @@ drive_is_cd_device (GDrive *gdrive)
 
         DEBUG_PRINT ("Got device: %s\n", device);
 
-        monitor = brasero_medium_monitor_get_default ();
+	/* FIXME: since we call the monitor, the library should be initialized.
+	 * To avoid all the initializing we'll be able to use the new GIO API
+	 * (#594649 -  Have a way to detect optical drives) */
+	ensure_initialized();
+
+	monitor = brasero_medium_monitor_get_default ();
         drive = brasero_medium_monitor_get_drive (monitor, device);
         g_object_unref (monitor);
         g_free (device);
@@ -591,6 +629,11 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
 		BraseroMedia		 media;
 		BraseroTrackType	*type;
 
+		/* Reminder: the following is not needed since it is already 
+		 * called in drive_is_cd_device ().
+		 * ensure_initialized();
+		 */
+
                 device_path = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
 		monitor = brasero_medium_monitor_get_default ();
 		bdrive = brasero_medium_monitor_get_drive (monitor, device_path);
@@ -985,22 +1028,7 @@ nautilus_disc_burn_register_type (GTypeModule *module)
 void
 nautilus_module_initialize (GTypeModule *module)
 {
-	GConfClient *client;
-
         DEBUG_PRINT ("Initializing nautilus-disc-recorder\n");
-
-	client = gconf_client_get_default ();
-	if (gconf_client_get_bool (client, "/apps/brasero/nautilus-extension-debug", NULL)) {
-		brasero_media_library_set_debug (TRUE);
-		brasero_burn_library_set_debug (TRUE);
-	}
-	g_object_unref (client);
-
-	brasero_media_library_start ();
-        brasero_burn_library_start (NULL, NULL);
-
-        DEBUG_PRINT ("Libbrasero-media started\n");
-
         nautilus_disc_burn_register_type (module);
 }
 
